#ifndef DIALSET_H_INCLUDED
#define DIALSET_H_INCLUDED

#include <qstring.h>
#include <qintdict.h>

class DspAction;

class DialKey
{
public:
	DialKey( const QString &initname, const QString &fullName = QString::null );
	~DialKey();

	void setName( const QString &newname );
	const QString &getName() const { return name; }

	void setFullName( const QString &newfull );
	const QString &getFullName() const { return fullname; }

	unsigned int getFreq( int id ) { return freq[ id ]; }
	void setFreq( int id, unsigned int f );

	unsigned int getHoldLength() const { return holdlength; }
	unsigned int getPostWait() const { return postwait; }

	void setHoldLength( unsigned int h );
	void setPostWait( unsigned int p );

private:
	unsigned int freq[ 3 ];
	unsigned int holdlength;
	unsigned int postwait;
	QString name;
	QString fullname;
};

class DialSet
{
public:
	DialSet();
	virtual ~DialSet();

	const QString &getName() const { return name; }
	void setName( const QString &newname );

	DspAction *playKey( long id, bool usetimings = false );
	DialKey *getKey( long id );
	void insertKey( long id, DialKey *data );

private:
	QString name;
	QIntDict<DialKey> keydata;
};

#endif // DIALSET_H_INCLUDED
