#include <qdom.h>
#include <dialset.h>
#include <dialsetparser.h>

DialSetParser::DialSetParser( const QString &xmlInput )
{
	QString xml = xmlInput;

	setValid( true );

	// This is the DOM document
	QDomDocument doc;

	// Load up the content!
	doc.setContent( xml );

	QDomElement elem = doc.documentElement().toElement();
	if( elem.tagName().lower() != "krad" ) {
		setValid( false );
		return;
	}

	elem = elem.firstChild().toElement();
	for( ; !elem.isNull(); elem = elem.nextSibling().toElement() ) {
		if( elem.tagName().lower() == "dialset" ) {
			DialSet *curset = new DialSet;
			dialsets.append( curset );

			// <DialSet name="ourname">
			curset->setName( elem.attribute( "name" ) );

			// Get the first child under this dialset, and parse it
			QDomElement dialsetcontents = elem.firstChild().toElement();
			parseDialSet( dialsetcontents, curset );
		}
	}
}

DialSetParser::~DialSetParser()
{
}

void DialSetParser::setValid( bool valid )
{
	isvalid = valid;
}

void DialSetParser::parseDialSet( QDomElement &elem, DialSet *curset )
{
	for( ; !elem.isNull(); elem = elem.nextSibling().toElement() ) {
		if( elem.tagName().lower() == "key" ) {
			DialKey *curkey = new DialKey( elem.attribute( "name" ), elem.attribute( "fullname" ) );

			// Insert key into current dialset
			curset->insertKey( elem.attribute( "id" ).toLong(), curkey );

			// Get the first child and parse
			QDomElement keycontents = elem.firstChild().toElement();
			parseKey( keycontents, curkey );
		}
	}
}

void DialSetParser::parseKey( QDomElement &elem, DialKey *curkey )
{
	int freqid = 0;

	for( ; !elem.isNull(); elem = elem.nextSibling().toElement() ) {
		if( elem.tagName().lower() == "tone" ) {
			curkey->setFreq( freqid++, elem.text().toUInt() );
		}
	}
}

DialSet *DialSetParser::getDialSet( int id )
{
	return dialsets.at( id );
}

int DialSetParser::count()
{
	return dialsets.count();
}

